@@ -3,6 +3,9 @@ from checkerboard import checkerboard
 import itk
 import pytest
 import numpy as np
+from itk_napari_conversion import image_layer_from_image
+from itk_napari_conversion import image_from_image_layer
+import napari
 
 # this is your plugin name declared in your napari.plugins entry point
 MY_PLUGIN_NAME = "napari-checkerboard"
@@ -15,12 +18,13 @@ def image_generator(x1, x2, y1, y2, data_dir='none'):
     image = np.zeros([100, 100], np.float32)
     image[y1:y2, x1:x2] = 1
     image = itk.image_view_from_array(image)
+    image = image_layer_from_image(image)
     return image
 
 
 def checkerboard_filter(*args, **kwargs):
-    filter = checkerboard.checkerboard()
-    return filter(*args, **kwargs)
+    cb_filter = checkerboard.checkerboard()
+    return cb_filter(*args, **kwargs)
 
 
 # @pytest.mark.parametrize("widget_name", MY_WIDGET_NAMES)
@@ -41,4 +45,4 @@ def test_checkerboard():
     image1 = image_generator(25, 75, 25, 75)
     image2 = image_generator(1, 51, 10, 60)
     result_image = checkerboard_filter(image1, image2, pattern=4)
-    assert type(result_image[0]) == np.ndarray
+    assert isinstance(result_image, napari.layers.Image)
